/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package chtdecoder.view;

import java.awt.Button;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Label;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

/**
 * A dialog box for short information messages.
 *
 * @author John David Ratliff
 * @version 1.1, 09/14/04
 */
public class MessageDialog extends java.awt.Dialog {
    private Button dismissButton;
    private Label messageLabel;
    private String message;

    /**
     * Creates a new MessageDialog object.
     *
     * @param parent The parent frame.
     * @param title The title of this MessageDialog.
     * @param message The message of this MessageDialog.
     */
    public MessageDialog(java.awt.Frame parent, String title, String message) {
        super(parent, title, true);

        this.setMessage(message);
        initComponents();
    }

    /**
     * Initializes the components of this MessageDialog.
     */
    private void initComponents() {
        GridBagConstraints gridBagConstraints;

        messageLabel = new Label();
        dismissButton = new Button();

        setLayout(new GridBagLayout());

        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent event) {
                    closeDialog();
                }
            });

        messageLabel.setText(this.getMessage());
        gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.fill = GridBagConstraints.HORIZONTAL;
        gridBagConstraints.insets = new Insets(5, 5, 5, 5);
        gridBagConstraints.weightx = 1.0;
        add(messageLabel, gridBagConstraints);

        dismissButton.setLabel("Dismiss");
        dismissButton.addActionListener(new ActionListener() {
                public void actionPerformed(ActionEvent event) {
                    closeDialog();
                }
            });

        gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        add(dismissButton, gridBagConstraints);

        pack();
    }

    /**
     * Called when this dialog is closed.
     */
    private void closeDialog() {
        setVisible(false);
        dispose();
    }

    /**
     * Sets the message of this dialog.
     *
     * @param message The message.
     */
    public void setMessage(String message) {
        this.message = message;
    }

    /**
     * Gets the message of this dialog.
     *
     * @return The message.
     */
    public String getMessage() {
        return this.message;
    }

    /**
     * Returns a String representation of this Message.
     *
     * @return A String representation.
     */
    public String toString() {
        return "MessageDialog[title=" + getTitle() + ", message=" +
               this.getMessage() + "]";
    }
}
